#ifndef _AMAP_INC_H

#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <ctype.h>
#include <stdlib.h>
#include <stdarg.h>
#include <signal.h>
#include <string.h>
#include <strings.h>
#include <sys/time.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <arpa/inet.h>
#include <netdb.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <fcntl.h>
#include <time.h>
#include <errno.h>
#include <sys/resource.h>
#include <sys/wait.h>
#include "pcre-3.9/pcre.h"
#ifdef OPENSSL
 #include <openssl/ssl.h>
 #include <openssl/err.h>
#endif

#define _AMAP_INC_H
#endif
